@@ -1,3 +1,5 @@
+# pylint: disable=wrong-import-order
+
 from datetime import datetime
 from typing import Optional
 
@@ -6,19 +8,19 @@ from asgiref.sync import sync_to_async
 from sqlalchemy.dialects.postgresql import insert
 from sqlalchemy.sql.expression import and_
 
-from spellbot.database import DatabaseSession
-from spellbot.models.award import GuildAward
-from spellbot.models.guild import Guild
-from spellbot.services import BaseService
+from ..database import DatabaseSession
+from ..models import Guild, GuildAward
 
 
-class GuildsService(BaseService):
+class GuildsService:
     def __init__(self):
         self.guild: Optional[Guild] = None
 
     @sync_to_async()
     def upsert(self, guild: discord.Guild) -> None:
-        name = guild.name[: Guild.name.property.columns[0].type.length]  # type: ignore
+        name_max_len = Guild.name.property.columns[0].type.length  # type: ignore
+        raw_name = getattr(guild, "name", "")
+        name = raw_name[:name_max_len]
         values = {
             "xid": guild.id,
             "name": name,
@@ -65,10 +67,12 @@ class GuildsService(BaseService):
         return self.guild.show_points
 
     @sync_to_async()
-    def set_motd(self, message: str) -> None:
-        assert self.guild
-        motd = message[: Guild.motd.property.columns[0].type.length]  # type: ignore
-        self.guild.motd = motd  # type: ignore
+    def set_motd(self, message: Optional[str] = None) -> None:
+        if message:
+            motd = message[: Guild.motd.property.columns[0].type.length]  # type: ignore
+            self.guild.motd = motd  # type: ignore
+        else:
+            self.guild.motd = ""  # type: ignore
         DatabaseSession.commit()
 
     @sync_to_async()
@@ -115,9 +119,9 @@ class GuildsService(BaseService):
                 and_(
                     GuildAward.guild_xid == self.guild.xid,
                     GuildAward.count == count,
-                )
+                ),
             )
-            .one_or_none()
+            .one_or_none(),
         )
 
     @sync_to_async
